==> chamilo-1.11.26.zip: chamilo-1.11.26/plugin/ai_helper/lang/spanish.php <==
<?php
/* For license terms, see /license.txt */

$strings['plugin_title'] = 'Asistente de IA.';
$strings['plugin_comment'] = 'Este plugin se integra en la plataforma para habilitar la generación automatizada de contenido inteligente, como preguntas de elección múltiple.';
$strings['Description'] = 'Debido a que la Inteligencia Artificial (para usar el término amplio) disponible ahora nos permite solicitar que se generen textos significativos, podemos usar esos sistemas para generar contenido previamente y luego dejar que el maestro/entrenador revise el contenido antes de publicarlo..';
$strings['tool_enable'] = 'Habilitar complemento';
$strings['api_name'] = 'API IA para conectar';
$strings['api_key'] = 'Clave API';
$strings['api_key_help'] = 'Clave secreta generada para su API de IA';
$strings['organization_id'] = 'Identificación de la organización';
$strings['organization_id_help'] = 'En caso de que su cuenta API sea de una organización.';
$strings['OpenAI'] = 'OpenAI';
$strings['tool_lp_enable'] = "Activarlo en las lecciones";
$strings['tool_quiz_enable'] = "Activarlo en los ejercicios";
$strings['tokens_limit'] = "Limite de tokens IA";
$strings['tokens_limit_help'] = 'Limitar la cantidad máxima de tokens disponibles por usuario por mes para evitar un alto costo de servicio.';
$strings['ErrorTokensLimit'] = 'Lo sentimos, ha alcanzado la cantidad máxima de tokens o solicitudes configuradas por el administrador de la plataforma para el mes calendario actual. Comuníquese con su equipo de soporte o espere hasta el próximo mes antes de poder enviar nuevas solicitudes a AI Helper.';

==> chamilo-1.11.32.zip: chamilo-1.11.32/plugin/ai_helper/lang/spanish.php <==
<?php
/* For license terms, see /license.txt */

$strings['plugin_title'] = 'Asistente de IA.';
$strings['plugin_comment'] = 'Este plugin se integra en la plataforma para habilitar la generación automatizada de contenido inteligente, como preguntas de elección múltiple.';
$strings['Description'] = 'Debido a que la Inteligencia Artificial (para usar el término amplio) disponible ahora nos permite solicitar que se generen textos significativos, podemos usar esos sistemas para generar contenido previamente y luego dejar que el maestro/entrenador revise el contenido antes de publicarlo..';
$strings['tool_enable'] = 'Habilitar complemento';
$strings['api_name'] = 'API IA para conectar';
$strings['api_key'] = 'Clave API';
$strings['api_key_help'] = 'Clave secreta generada para su API de IA';
$strings['organization_id'] = 'Identificación de la organización';
$strings['organization_id_help'] = 'En caso de que su cuenta API sea de una organización.';
$strings['OpenAI'] = 'OpenAI';
$strings['tool_lp_enable'] = "Activarlo en las lecciones";
$strings['tool_quiz_enable'] = "Activarlo en los ejercicios";
$strings['tokens_limit'] = "Limite de tokens IA";
$strings['tokens_limit_help'] = 'Limitar la cantidad máxima de tokens disponibles por usuario por mes para evitar un alto costo de servicio.';
$strings['ErrorTokensLimit'] = 'Lo sentimos, ha alcanzado la cantidad máxima de tokens o solicitudes configuradas por el administrador de la plataforma para el mes calendario actual. Comuníquese con su equipo de soporte o espere hasta el próximo mes antes de poder enviar nuevas solicitudes a AI Helper.';
$strings['DeepSeek'] = 'DeepSeek';
$strings['deepseek_api_key'] = 'Clave API de DeepSeek';
$strings['deepseek_api_key_help'] = 'Clave API para conectarse con DeepSeek.';
